# litestar-sendparcel

Litestar adapter for [python-sendparcel](https://github.com/your-org/python-sendparcel) — a framework-agnostic parcel shipping library.

## Contents

```{toctree}
:maxdepth: 2

quickstart
configuration
api
```
